@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Get XML.
 has xml => (
@@ -81,7 +81,7 @@ For more information about Kazan Map, click L<here|https://en.wikipedia.org/wiki
 =item C<get_lines()>
 
  Get lines in metro map.
- Returns reference to array with Map::Tube::Line objects.
+ Returns reference to unsorted array with Map::Tube::Line objects.
 
 =item C<get_node_by_id($station_id)>
 
@@ -218,6 +218,50 @@ For more information about Kazan Map, click L<here|https://en.wikipedia.org/wiki
  # Output:
  # Центральная линия
 
+=head1 EXAMPLE5
+
+ # Pragmas.
+ use strict;
+ use warnings;
+
+ # Modules.
+ use Encode qw(decode_utf8 encode_utf8);
+ use Map::Tube::Kazan;
+
+ # Arguments.
+ if (@ARGV < 1) {
+         print STDERR "Usage: $0 line\n";
+         exit 1;
+ }
+ my $line = decode_utf8($ARGV[0]);
+
+ # Object.
+ my $obj = Map::Tube::Kazan->new;
+
+ # Get stations for line.
+ my $stations_ar = $obj->get_stations($line);
+
+ # Print out.
+ map { print encode_utf8($_->name)."\n"; } @{$stations_ar};
+
+ # Output:
+ # Usage: __PROG__ line
+
+ # Output with 'foo' argument.
+ # Map::Tube::get_stations(): ERROR: Invalid Line Name [foo]. (status: 105) file __PROG__ on line __LINE__
+
+ # Output with 'Центральная линия' argument.
+ # Авиастроительная
+ # Северный вокзал
+ # Яшьлек
+ # Козья слобода
+ # Кремлёвская
+ # Площадь Габдуллы Тукая
+ # Суконная слобода
+ # Аметьево
+ # Горки
+ # Проспект Победы
+
 =head1 DEPENDENCIES
 
 L<File::Share>,
@@ -249,18 +293,18 @@ L<https://github.com/tupinek/Map-Tube-Kazan>
 
 =head1 AUTHOR
 
-Michal Špaček L<mailto:skim@cpan.org>
+Michal Josef Špaček L<mailto:skim@cpan.org>
 
 L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2014-2015 Michal Špaček
+ © 2014-2017 Michal Josef Špaček
  Artistic License
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
